@@ -8,7 +8,6 @@ import zipfile
 import numpy as np
 import pytest
 import requests
-from numpy.testing import assert_allclose, assert_equal
 
 from hyperspy import signals
 from hyperspy.io import load
@@ -32,7 +31,6 @@ if not TEST_FILES_OK:
 
         SHA256SUM_GOT = hashlib.sha256(r.content).hexdigest()
         if SHA256SUM_GOT == SHA256SUM:
-            ZIPF = os.path.join(TMP_DIR.name, "edax_files.zip")
             with open(ZIPF, 'wb') as f:
                 f.write(r.content)
             TEST_FILES_OK = True
@@ -94,15 +92,15 @@ class TestSpcSpectrum_v061_xrf:
             'Signal']
 
         # Testing SEM parameters
-        assert_allclose(30, sem_dict['beam_energy'])
-        assert_allclose(0, sem_dict['Stage']['tilt_alpha'])
+        np.testing.assert_allclose(30, sem_dict['beam_energy'])
+        np.testing.assert_allclose(0, sem_dict['Stage']['tilt_alpha'])
 
         # Testing EDS parameters
-        assert_allclose(45, eds_dict['azimuth_angle'])
-        assert_allclose(35, eds_dict['elevation_angle'])
-        assert_allclose(137.92946, eds_dict['energy_resolution_MnKa'],
+        np.testing.assert_allclose(45, eds_dict['azimuth_angle'])
+        np.testing.assert_allclose(35, eds_dict['elevation_angle'])
+        np.testing.assert_allclose(137.92946, eds_dict['energy_resolution_MnKa'],
                         atol=1E-5)
-        assert_allclose(2561.0, eds_dict['live_time'], atol=1E-6)
+        np.testing.assert_allclose(2561.0, eds_dict['live_time'], atol=1E-6)
 
         # Testing elements
         assert ({'Al', 'Ca', 'Cl', 'Cr', 'Fe', 'K', 'Mg', 'Mn', 'Si', 'Y'} ==
@@ -127,13 +125,13 @@ class TestSpcSpectrum_v061_xrf:
         spc_header = TestSpcSpectrum_v061_xrf.spc_loadAll.original_metadata[
             'spc_header']
 
-        assert_allclose(4, spc_header['analysisType'])
-        assert_allclose(4, spc_header['analyzerType'])
-        assert_allclose(2013, spc_header['collectDateYear'])
-        assert_allclose(9, spc_header['collectDateMon'])
-        assert_allclose(26, spc_header['collectDateDay'])
-        assert_equal(b'Garnet1.', spc_header['fileName'].view('|S8')[0])
-        assert_allclose(45, spc_header['xRayTubeZ'])
+        np.testing.assert_allclose(4, spc_header['analysisType'])
+        np.testing.assert_allclose(4, spc_header['analyzerType'])
+        np.testing.assert_allclose(2013, spc_header['collectDateYear'])
+        np.testing.assert_allclose(9, spc_header['collectDateMon'])
+        np.testing.assert_allclose(26, spc_header['collectDateDay'])
+        np.testing.assert_equal(b'Garnet1.', spc_header['fileName'].view('|S8')[0])
+        np.testing.assert_allclose(45, spc_header['xRayTubeZ'])
 
 
 class TestSpcSpectrum_v070_eds:
@@ -170,15 +168,15 @@ class TestSpcSpectrum_v070_eds:
             'Signal']
 
         # Testing SEM parameters
-        assert_allclose(22, sem_dict['beam_energy'])
-        assert_allclose(0, sem_dict['Stage']['tilt_alpha'])
+        np.testing.assert_allclose(22, sem_dict['beam_energy'])
+        np.testing.assert_allclose(0, sem_dict['Stage']['tilt_alpha'])
 
         # Testing EDS parameters
-        assert_allclose(0, eds_dict['azimuth_angle'])
-        assert_allclose(34, eds_dict['elevation_angle'])
-        assert_allclose(129.31299, eds_dict['energy_resolution_MnKa'],
+        np.testing.assert_allclose(0, eds_dict['azimuth_angle'])
+        np.testing.assert_allclose(34, eds_dict['elevation_angle'])
+        np.testing.assert_allclose(129.31299, eds_dict['energy_resolution_MnKa'],
                         atol=1E-5)
-        assert_allclose(50.000004, eds_dict['live_time'], atol=1E-6)
+        np.testing.assert_allclose(50.000004, eds_dict['live_time'], atol=1E-6)
 
         # Testing elements
         assert ({'Al', 'C', 'Ce', 'Cu', 'F', 'Ho', 'Mg', 'O'} ==
@@ -203,15 +201,15 @@ class TestSpcSpectrum_v070_eds:
         spc_header = TestSpcSpectrum_v070_eds.spc_loadAll.original_metadata[
             'spc_header']
 
-        assert_allclose(4, spc_header['analysisType'])
-        assert_allclose(5, spc_header['analyzerType'])
-        assert_allclose(2016, spc_header['collectDateYear'])
-        assert_allclose(4, spc_header['collectDateMon'])
-        assert_allclose(19, spc_header['collectDateDay'])
-        assert_equal(b'C:\\ProgramData\\EDAX\\jtaillon\\Cole\\Mapping\\Lsm\\'
+        np.testing.assert_allclose(4, spc_header['analysisType'])
+        np.testing.assert_allclose(5, spc_header['analyzerType'])
+        np.testing.assert_allclose(2016, spc_header['collectDateYear'])
+        np.testing.assert_allclose(4, spc_header['collectDateMon'])
+        np.testing.assert_allclose(19, spc_header['collectDateDay'])
+        np.testing.assert_equal(b'C:\\ProgramData\\EDAX\\jtaillon\\Cole\\Mapping\\Lsm\\'
                      b'GFdCr\\950\\Area 1\\spectrum20160419153851427_0.spc',
                      spc_header['longFileName'].view('|S256')[0])
-        assert_allclose(0, spc_header['xRayTubeZ'])
+        np.testing.assert_allclose(0, spc_header['xRayTubeZ'])
 
 
 class TestSpdMap_070_eds:
@@ -267,15 +265,15 @@ class TestSpdMap_070_eds:
         signal_dict = TestSpdMap_070_eds.spd.metadata.as_dictionary()['Signal']
 
         # Testing SEM parameters
-        assert_allclose(22, sem_dict['beam_energy'])
-        assert_allclose(0, sem_dict['Stage']['tilt_alpha'])
+        np.testing.assert_allclose(22, sem_dict['beam_energy'])
+        np.testing.assert_allclose(0, sem_dict['Stage']['tilt_alpha'])
 
         # Testing EDS parameters
-        assert_allclose(0, eds_dict['azimuth_angle'])
-        assert_allclose(34, eds_dict['elevation_angle'])
-        assert_allclose(126.60252, eds_dict['energy_resolution_MnKa'],
+        np.testing.assert_allclose(0, eds_dict['azimuth_angle'])
+        np.testing.assert_allclose(34, eds_dict['elevation_angle'])
+        np.testing.assert_allclose(126.60252, eds_dict['energy_resolution_MnKa'],
                         atol=1E-5)
-        assert_allclose(2621.4399, eds_dict['live_time'], atol=1E-4)
+        np.testing.assert_allclose(2621.4399, eds_dict['live_time'], atol=1E-4)
 
         # Testing elements
         assert {'Ce', 'Co', 'Cr', 'Fe', 'Gd', 'La', 'Mg', 'O',
@@ -310,8 +308,8 @@ class TestSpdMap_070_eds:
 
     def test_ipr_reading(self):
         ipr_header = TestSpdMap_070_eds.spd.original_metadata['ipr_header']
-        assert_allclose(0.014235896, ipr_header['mppX'])
-        assert_allclose(0.014227346, ipr_header['mppY'])
+        np.testing.assert_allclose(0.014235896, ipr_header['mppX'])
+        np.testing.assert_allclose(0.014227346, ipr_header['mppY'])
 
     def test_spc_reading(self):
         # Test to make sure that spc metadata matches spd metadata
@@ -323,19 +321,19 @@ class TestSpdMap_070_eds:
             'Acquisition_instrument']['SEM']
         eds_dict = sem_dict['Detector']['EDS']
 
-        assert_allclose(spc_header.azimuth,
+        np.testing.assert_allclose(spc_header.azimuth,
                         eds_dict['azimuth_angle'])
-        assert_allclose(spc_header.detReso,
+        np.testing.assert_allclose(spc_header.detReso,
                         eds_dict['energy_resolution_MnKa'])
-        assert_allclose(spc_header.elevation,
+        np.testing.assert_allclose(spc_header.elevation,
                         eds_dict['elevation_angle'])
-        assert_allclose(spc_header.liveTime,
+        np.testing.assert_allclose(spc_header.liveTime,
                         eds_dict['live_time'])
-        assert_allclose(spc_header.evPerChan,
+        np.testing.assert_allclose(spc_header.evPerChan,
                         TestSpdMap_070_eds.spd.axes_manager[2].scale * 1000)
-        assert_allclose(spc_header.kV,
+        np.testing.assert_allclose(spc_header.kV,
                         sem_dict['beam_energy'])
-        assert_allclose(spc_header.numElem,
+        np.testing.assert_allclose(spc_header.numElem,
                         len(elements))
 
 
@@ -392,15 +390,15 @@ class TestSpdMap_061_xrf:
         signal_dict = TestSpdMap_061_xrf.spd.metadata.as_dictionary()['Signal']
 
         # Testing SEM parameters
-        assert_allclose(30, sem_dict['beam_energy'])
-        assert_allclose(0, sem_dict['Stage']['tilt_alpha'])
+        np.testing.assert_allclose(30, sem_dict['beam_energy'])
+        np.testing.assert_allclose(0, sem_dict['Stage']['tilt_alpha'])
 
         # Testing EDS parameters
-        assert_allclose(45, eds_dict['azimuth_angle'])
-        assert_allclose(35, eds_dict['elevation_angle'])
-        assert_allclose(137.92946, eds_dict['energy_resolution_MnKa'],
+        np.testing.assert_allclose(45, eds_dict['azimuth_angle'])
+        np.testing.assert_allclose(35, eds_dict['elevation_angle'])
+        np.testing.assert_allclose(137.92946, eds_dict['energy_resolution_MnKa'],
                         atol=1E-5)
-        assert_allclose(2561.0, eds_dict['live_time'], atol=1E-4)
+        np.testing.assert_allclose(2561.0, eds_dict['live_time'], atol=1E-4)
 
         # Testing elements
         assert {'Al', 'Ca', 'Cl', 'Cr', 'Fe', 'K', 'Mg', 'Mn', 'Si',
@@ -435,8 +433,8 @@ class TestSpdMap_061_xrf:
 
     def test_ipr_reading(self):
         ipr_header = TestSpdMap_061_xrf.spd.original_metadata['ipr_header']
-        assert_allclose(565.1920166015625, ipr_header['mppX'])
-        assert_allclose(565.1920166015625, ipr_header['mppY'])
+        np.testing.assert_allclose(565.1920166015625, ipr_header['mppX'])
+        np.testing.assert_allclose(565.1920166015625, ipr_header['mppY'])
 
     def test_spc_reading(self):
         # Test to make sure that spc metadata matches spd_061_xrf metadata
@@ -448,17 +446,17 @@ class TestSpdMap_061_xrf:
             'Acquisition_instrument']['SEM']
         eds_dict = sem_dict['Detector']['EDS']
 
-        assert_allclose(spc_header.azimuth,
+        np.testing.assert_allclose(spc_header.azimuth,
                         eds_dict['azimuth_angle'])
-        assert_allclose(spc_header.detReso,
+        np.testing.assert_allclose(spc_header.detReso,
                         eds_dict['energy_resolution_MnKa'])
-        assert_allclose(spc_header.elevation,
+        np.testing.assert_allclose(spc_header.elevation,
                         eds_dict['elevation_angle'])
-        assert_allclose(spc_header.liveTime,
+        np.testing.assert_allclose(spc_header.liveTime,
                         eds_dict['live_time'])
-        assert_allclose(spc_header.evPerChan,
+        np.testing.assert_allclose(spc_header.evPerChan,
                         TestSpdMap_061_xrf.spd.axes_manager[2].scale * 1000)
-        assert_allclose(spc_header.kV,
+        np.testing.assert_allclose(spc_header.kV,
                         sem_dict['beam_energy'])
-        assert_allclose(spc_header.numElem,
+        np.testing.assert_allclose(spc_header.numElem,
                         len(elements))
