@@ -32,11 +32,11 @@ import h5py
 import numpy as np
 import pytest
 from dateutil import tz
-from numpy.testing import assert_allclose
 
 from hyperspy.io import load
 from hyperspy.misc.test_utils import assert_deep_almost_equal
-from hyperspy.signals import BaseSignal, EDSTEMSpectrum, Signal1D, Signal2D
+from hyperspy.signals import (BaseSignal, EDSTEMSpectrum, Signal1D, Signal2D,
+                              ComplexSignal2D)
 
 my_path = os.path.dirname(__file__)
 
@@ -218,7 +218,6 @@ class TestReadSeveralDatasets:
     def test_load_file(self):
         s = load(self.hdf5_dataset_path)
         assert len(s) == len(self.group_path_list)
-        title_list = [s_temp.metadata.General.title for s_temp in s]
         for _s, path in zip(s, self.group_path_list):
             assert _s.metadata.General.title in path
 
@@ -319,7 +318,7 @@ class TestFeiEMD():
                           'time': '09:56:41',
                           'time_zone': 'BST',
                           'title': 'HAADF'},
-              'Signal': {'binned': False, 'signal_type': 'image'},
+              'Signal': {'binned': False, 'signal_type': ''},
               '_HyperSpy': {'Folding': {'original_axes_manager': None,
                                         'original_shape': None,
                                         'signal_unfolded': False,
@@ -342,11 +341,11 @@ class TestFeiEMD():
                                          'fei_emd_image.npy'))
         assert signal.axes_manager[0].name == 'x'
         assert signal.axes_manager[0].units == 'µm'
-        assert_allclose(signal.axes_manager[0].scale, 0.00530241, rtol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[0].scale, 0.00530241, rtol=1E-5)
         assert signal.axes_manager[1].name == 'y'
         assert signal.axes_manager[1].units == 'µm'
-        assert_allclose(signal.axes_manager[1].scale, 0.00530241, rtol=1E-5)
-        assert_allclose(signal.data, fei_image)
+        np.testing.assert_allclose(signal.axes_manager[1].scale, 0.00530241, rtol=1E-5)
+        np.testing.assert_allclose(signal.data, fei_image)
         assert_deep_almost_equal(signal.metadata.as_dictionary(), md)
         assert isinstance(signal, Signal2D)
 
@@ -386,15 +385,15 @@ class TestFeiEMD():
         assert signal.axes_manager[0].name == 'x'
         assert signal.axes_manager[0].size == 10
         assert signal.axes_manager[0].units == 'nm'
-        assert_allclose(signal.axes_manager[0].scale, 1.234009, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[0].scale, 1.234009, atol=1E-5)
         assert signal.axes_manager[1].name == 'y'
         assert signal.axes_manager[1].size == 50
         assert signal.axes_manager[1].units == 'nm'
-        assert_allclose(signal.axes_manager[1].scale, 1.234009, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[1].scale, 1.234009, atol=1E-5)
         assert signal.axes_manager[2].name == 'X-ray energy'
         assert signal.axes_manager[2].size == 4096
         assert signal.axes_manager[2].units == 'keV'
-        assert_allclose(signal.axes_manager[2].scale, 0.005, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[2].scale, 0.005, atol=1E-5)
 
         signal0 = s[0]
         if lazy:
@@ -404,11 +403,49 @@ class TestFeiEMD():
         assert signal0.axes_manager[0].name == 'x'
         assert signal0.axes_manager[0].size == 10
         assert signal0.axes_manager[0].units == 'nm'
-        assert_allclose(signal0.axes_manager[0].scale, 1.234009, atol=1E-5)
+        np.testing.assert_allclose(signal0.axes_manager[0].scale, 1.234009, atol=1E-5)
         assert signal0.axes_manager[1].name == 'y'
         assert signal0.axes_manager[1].size == 50
         assert signal0.axes_manager[1].units == 'nm'
 
+        s = load(os.path.join(
+            self.fei_files_path, 'fei_SI_SuperX-HAADF_10frames_10x50.emd'),
+            lazy=lazy,
+            load_SI_image_stack=True)
+        signal = s[1]
+        if lazy:
+            assert signal._lazy
+            signal.compute(close_file=True)
+        assert isinstance(signal, EDSTEMSpectrum)
+        assert signal.axes_manager[0].name == 'x'
+        assert signal.axes_manager[0].size == 10
+        assert signal.axes_manager[0].units == 'nm'
+        np.testing.assert_allclose(signal.axes_manager[0].scale, 1.234009, atol=1E-5)
+        assert signal.axes_manager[1].name == 'y'
+        assert signal.axes_manager[1].size == 50
+        assert signal.axes_manager[1].units == 'nm'
+        np.testing.assert_allclose(signal.axes_manager[1].scale, 1.234009, atol=1E-5)
+        assert signal.axes_manager[2].name == 'X-ray energy'
+        assert signal.axes_manager[2].size == 4096
+        assert signal.axes_manager[2].units == 'keV'
+        np.testing.assert_allclose(signal.axes_manager[2].scale, 0.005, atol=1E-5)
+
+        signal0 = s[0]
+        if lazy:
+            assert signal0._lazy
+            signal0.compute(close_file=True)
+        assert isinstance(signal0, Signal2D)
+        assert signal0.axes_manager[0].name == 'Time'
+        assert signal0.axes_manager[0].size == 10
+        assert signal0.axes_manager[0].units == 's'
+        assert signal0.axes_manager[1].name == 'x'
+        assert signal0.axes_manager[1].size == 10
+        assert signal0.axes_manager[1].units == 'nm'
+        np.testing.assert_allclose(signal0.axes_manager[1].scale, 1.234009, atol=1E-5)
+        assert signal0.axes_manager[2].name == 'y'
+        assert signal0.axes_manager[2].size == 50
+        assert signal0.axes_manager[2].units == 'nm'
+
         s = load(os.path.join(self.fei_files_path,
                               'fei_SI_SuperX-HAADF_10frames_10x50.emd'),
                  sum_frames=False,
@@ -424,19 +461,19 @@ class TestFeiEMD():
         assert signal.axes_manager[0].name == 'x'
         assert signal.axes_manager[0].size == 10
         assert signal.axes_manager[0].units == 'nm'
-        assert_allclose(signal.axes_manager[0].scale, 1.234009, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[0].scale, 1.234009, atol=1E-5)
         assert signal.axes_manager[1].name == 'y'
         assert signal.axes_manager[1].size == 50
         assert signal.axes_manager[1].units == 'nm'
-        assert_allclose(signal.axes_manager[1].scale, 1.234009, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[1].scale, 1.234009, atol=1E-5)
         assert signal.axes_manager[2].name == 'Time'
         assert signal.axes_manager[2].size == 10
         assert signal.axes_manager[2].units == 's'
-        assert_allclose(signal.axes_manager[2].scale, 0.76800, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[2].scale, 0.76800, atol=1E-5)
         assert signal.axes_manager[3].name == 'X-ray energy'
         assert signal.axes_manager[3].size == 16
         assert signal.axes_manager[3].units == 'keV'
-        assert_allclose(signal.axes_manager[3].scale, 1.28, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[3].scale, 1.28, atol=1E-5)
 
         s = load(os.path.join(self.fei_files_path,
                               'fei_SI_SuperX-HAADF_10frames_10x50.emd'),
@@ -454,19 +491,19 @@ class TestFeiEMD():
         assert signal.axes_manager[0].name == 'x'
         assert signal.axes_manager[0].size == 10
         assert signal.axes_manager[0].units == 'nm'
-        assert_allclose(signal.axes_manager[0].scale, 1.234009, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[0].scale, 1.234009, atol=1E-5)
         assert signal.axes_manager[1].name == 'y'
         assert signal.axes_manager[1].size == 50
         assert signal.axes_manager[1].units == 'nm'
-        assert_allclose(signal.axes_manager[1].scale, 1.234009, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[1].scale, 1.234009, atol=1E-5)
         assert signal.axes_manager[2].name == 'Time'
         assert signal.axes_manager[2].size == 5
         assert signal.axes_manager[2].units == 's'
-        assert_allclose(signal.axes_manager[2].scale, 0.76800, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[2].scale, 0.76800, atol=1E-5)
         assert signal.axes_manager[3].name == 'X-ray energy'
         assert signal.axes_manager[3].size == 16
         assert signal.axes_manager[3].units == 'keV'
-        assert_allclose(signal.axes_manager[3].scale, 1.28, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[3].scale, 1.28, atol=1E-5)
 
         s = load(os.path.join(self.fei_files_path,
                               'fei_SI_SuperX-HAADF_10frames_10x50.emd'),
@@ -484,19 +521,19 @@ class TestFeiEMD():
         assert signal.axes_manager[0].name == 'x'
         assert signal.axes_manager[0].size == 10
         assert signal.axes_manager[0].units == 'nm'
-        assert_allclose(signal.axes_manager[0].scale, 1.234009, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[0].scale, 1.234009, atol=1E-5)
         assert signal.axes_manager[1].name == 'y'
         assert signal.axes_manager[1].size == 50
         assert signal.axes_manager[1].units == 'nm'
-        assert_allclose(signal.axes_manager[1].scale, 1.234009, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[1].scale, 1.234009, atol=1E-5)
         assert signal.axes_manager[2].name == 'Time'
         assert signal.axes_manager[2].size == 6
         assert signal.axes_manager[2].units == 's'
-        assert_allclose(signal.axes_manager[2].scale, 0.76800, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[2].scale, 0.76800, atol=1E-5)
         assert signal.axes_manager[3].name == 'X-ray energy'
         assert signal.axes_manager[3].size == 16
         assert signal.axes_manager[3].units == 'keV'
-        assert_allclose(signal.axes_manager[3].scale, 1.28, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[3].scale, 1.28, atol=1E-5)
 
     @pytest.mark.parametrize("lazy", (True, False))
     def test_fei_emd_si_non_square_20frames(self, lazy):
@@ -512,15 +549,15 @@ class TestFeiEMD():
         assert signal.axes_manager[0].name == 'x'
         assert signal.axes_manager[0].size == 10
         assert signal.axes_manager[0].units == 'nm'
-        assert_allclose(signal.axes_manager[0].scale, 1.234009, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[0].scale, 1.234009, atol=1E-5)
         assert signal.axes_manager[1].name == 'y'
         assert signal.axes_manager[1].size == 50
         assert signal.axes_manager[1].units == 'nm'
-        assert_allclose(signal.axes_manager[1].scale, 1.234009, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[1].scale, 1.234009, atol=1E-5)
         assert signal.axes_manager[2].name == 'X-ray energy'
         assert signal.axes_manager[2].size == 4096
         assert signal.axes_manager[2].units == 'keV'
-        assert_allclose(signal.axes_manager[2].scale, 0.005, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[2].scale, 0.005, atol=1E-5)
 
     @pytest.mark.parametrize("lazy", (True, False))
     def test_fei_emd_si_non_square_20frames_2eV(self, lazy):
@@ -536,15 +573,15 @@ class TestFeiEMD():
         assert signal.axes_manager[0].name == 'x'
         assert signal.axes_manager[0].size == 10
         assert signal.axes_manager[0].units == 'nm'
-        assert_allclose(signal.axes_manager[0].scale, 1.234009, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[0].scale, 1.234009, atol=1E-5)
         assert signal.axes_manager[1].name == 'y'
         assert signal.axes_manager[1].size == 50
         assert signal.axes_manager[1].units == 'nm'
-        assert_allclose(signal.axes_manager[1].scale, 1.234009, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[1].scale, 1.234009, atol=1E-5)
         assert signal.axes_manager[2].name == 'X-ray energy'
         assert signal.axes_manager[2].size == 4096
         assert signal.axes_manager[2].units == 'keV'
-        assert_allclose(signal.axes_manager[2].scale, 0.002, atol=1E-5)
+        np.testing.assert_allclose(signal.axes_manager[2].scale, 0.002, atol=1E-5)
 
     @pytest.mark.parametrize("lazy", (True, False))
     def test_fei_emd_si_frame_range(self, lazy):
@@ -578,7 +615,7 @@ class TestFeiEMD():
             os.path.join(
                 self.fei_files_path,
                 '1532 Camera Ceta.emd'))
-        assert_allclose(signal.data, np.zeros((64, 64)))
+        np.testing.assert_allclose(signal.data, np.zeros((64, 64)))
         assert isinstance(signal, Signal2D)
         date, time = self._convert_datetime(1512055942.914275).split('T')
         assert signal.metadata.General.date == date
@@ -589,7 +626,7 @@ class TestFeiEMD():
             os.path.join(
                 self.fei_files_path,
                 '1854 Camera Ceta.emd'))
-        assert_allclose(signal.data, np.zeros((64, 64)))
+        np.testing.assert_allclose(signal.data, np.zeros((64, 64)))
         assert isinstance(signal, Signal2D)
 
     def _convert_datetime(self, unix_time):
@@ -621,3 +658,37 @@ class TestFeiEMD():
         plt.plot(frame_offsets, time_data)
         plt.xlabel('Frame offset')
         plt.xlabel('Loading time (s)')
+
+
+def test_fei_complex_loading():
+    signal = load(os.path.join(my_path, 'emd_files', 'fei_example_complex_fft.emd'))
+    assert isinstance(signal, ComplexSignal2D)
+
+
+def test_fei_no_frametime():
+    signal = load(os.path.join(my_path, 'emd_files', 'fei_example_tem_stack.emd'))
+    assert isinstance(signal, Signal2D)
+    assert signal.data.shape == (2, 3, 3)
+    assert signal.axes_manager["Time"].scale == 0.8
+
+
+def test_fei_dpc_loading():
+    signals = load(os.path.join(my_path, 'emd_files', 'fei_example_dpc_titles.emd'))
+    assert signals[0].metadata.General.title == "B-D"
+    assert signals[1].metadata.General.title == "DPC"
+    assert signals[2].metadata.General.title == "iDPC"
+    assert signals[3].metadata.General.title == "DF4-C"
+    assert signals[4].metadata.General.title == "DF4-B"
+    assert signals[5].metadata.General.title == "DF4-A"
+    assert signals[6].metadata.General.title == "A-C"
+    assert signals[7].metadata.General.title == "DF4-D"
+    assert signals[8].metadata.General.title == "Filtered iDPC"
+    assert isinstance(signals[0], Signal2D)
+    assert isinstance(signals[1], ComplexSignal2D)
+    assert isinstance(signals[2], Signal2D)
+    assert isinstance(signals[3], Signal2D)
+    assert isinstance(signals[4], Signal2D)
+    assert isinstance(signals[5], Signal2D)
+    assert isinstance(signals[6], Signal2D)
+    assert isinstance(signals[7], Signal2D)
+    assert isinstance(signals[8], Signal2D)
